@@ -20,19 +20,19 @@
 
 #include "bugzillalib.h"
 
-#include <QtCore/QtGlobal>
-#include <QtCore/QTextStream>
-#include <QtCore/QByteArray>
-#include <QtCore/QString>
+#include <QtGlobal>
+#include <QTextStream>
+#include <QByteArray>
+#include <QString>
 
-#include <QtXml/QDomNode>
-#include <QtXml/QDomNodeList>
-#include <QtXml/QDomElement>
-#include <QtXml/QDomNamedNodeMap>
+#include <QDomNode>
+#include <QDomNodeList>
+#include <QDomElement>
+#include <QDomNamedNodeMap>
 
 #include <KIO/Job>
 #include <KLocalizedString>
-#include <QDebug>
+#include "drkonqi_debug.h"
 
 #define MAKE_BUGZILLA_VERSION(a,b,c) (((a) << 16) | ((b) << 8) | (c))
 
@@ -62,11 +62,15 @@ BugzillaManager::BugzillaManager(const QString &bugTrackerUrl, QObject *parent)
         , m_logged(false)
         , m_searchJob(nullptr)
 {
-    m_xmlRpcClient = new KXmlRpc::Client(QUrl(m_bugTrackerUrl + "xmlrpc.cgi"), this);
-    m_xmlRpcClient->setUserAgent(QLatin1String("DrKonqi"));
+    m_xmlRpcClient = new KXmlRpc::Client(QUrl(m_bugTrackerUrl + QStringLiteral("xmlrpc.cgi")), this);
+    m_xmlRpcClient->setUserAgent(QStringLiteral("DrKonqi"));
     // Allow constructors for ReportInterface and assistant dialogs to finish.
     // We do not want them to be racing the remote Bugzilla database.
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    QMetaObject::invokeMethod (this, &BugzillaManager::lookupVersion, Qt::QueuedConnection);
+#else
     QMetaObject::invokeMethod (this, "lookupVersion", Qt::QueuedConnection);
+#endif
 }
 
 // BEGIN Checks of Bugzilla software versions.
@@ -99,7 +103,7 @@ void BugzillaManager::setFeaturesForVersion(const QString& version)
         digits << QLatin1String("0");
     }
     if (digits.count() > nVersionParts) {
-        qWarning() << QStringLiteral("Current Bugzilla version %1 has more than %2 parts. Check that this is not a problem.").arg(version).arg(nVersionParts);
+        qCWarning(DRKONQI_LOG) << QStringLiteral("Current Bugzilla version %1 has more than %2 parts. Check that this is not a problem.").arg(version).arg(nVersionParts);
     }
     int currentVersion = MAKE_BUGZILLA_VERSION(digits.at(0).toUInt(),
                              digits.at(1).toUInt(), digits.at(2).toUInt());
@@ -115,7 +119,7 @@ void BugzillaManager::setFeaturesForVersion(const QString& version)
         m_security = UsePasswords;
     }
 
-    qDebug() << "VERSION" << version << "SECURITY" << m_security;
+    qCDebug(DRKONQI_LOG) << "VERSION" << version << "SECURITY" << m_security;
 }
 // END Checks of Bugzilla software versions.
 
@@ -127,16 +131,16 @@ void BugzillaManager::callBugzilla(const char* method, const char* id,
     if (security == SecurityEnabled) {
         switch (m_security) {
         case UseTokens:
-            qDebug() << method << id << "using token";
+            qCDebug(DRKONQI_LOG) << method << id << "using token";
             args.insert(QLatin1String("Bugzilla_token"), m_token);
             break;
         case UsePasswords:
-            qDebug() << method << id << "using username" << m_username;
+            qCDebug(DRKONQI_LOG) << method << id << "using username" << m_username;
             args.insert(QLatin1String("Bugzilla_login"), m_username);
             args.insert(QLatin1String("Bugzilla_password"), m_password);
             break;
         case UseCookies:
-            qDebug() << method << id << "using cookies";
+            qCDebug(DRKONQI_LOG) << method << id << "using cookies";
             // Some KDE process other than Dr Konqi should provide cookies.
             break;
         }
@@ -183,7 +187,7 @@ QString BugzillaManager::getUsername() const
 //BEGIN Bugzilla Action methods
 void BugzillaManager::fetchBugReport(int bugnumber, QObject * jobOwner)
 {
-    QUrl url(m_bugTrackerUrl + QString(fetchBugUrl).arg(bugnumber));
+    QUrl url(m_bugTrackerUrl + QString::fromLatin1(fetchBugUrl).arg(bugnumber));
 
     if (!jobOwner) {
         jobOwner = this;
@@ -205,15 +209,15 @@ void BugzillaManager::searchBugs(const QStringList & products,
             product = products.at(0);
         } else  {
             Q_FOREACH(const QString & p, products) {
-                product += p + "&product=";
+                product += p + QStringLiteral("&product=");
             }
             product = product.mid(0,product.size()-9);
         }
     }
 
     QString url = QString(m_bugTrackerUrl) +
-                  QString(searchUrl).arg(product, comment.replace(' ' , '+'), date_start,
-                                         date_end, severity, QString(columns));
+                  QString::fromLatin1(searchUrl).arg(product, comment.replace(QLatin1Char(' ') , QLatin1Char('+')), date_start,
+                                         date_end, severity, QString::fromLatin1(columns));
 
     stopCurrentSearch();
 
@@ -288,7 +292,7 @@ void BugzillaManager::fetchProductInfo(const QString & product)
 //BEGIN Misc methods
 QString BugzillaManager::urlForBug(int bug_number) const
 {
-    return QString(m_bugTrackerUrl) + QString(showBugUrl).arg(bug_number);
+    return QString(m_bugTrackerUrl) + QString::fromLatin1(showBugUrl).arg(bug_number);
 }
 
 void BugzillaManager::stopCurrentSearch()
@@ -407,7 +411,7 @@ void BugzillaManager::fetchProductInfoFinished(const QVariantMap & map)
 
 void BugzillaManager::callMessage(const QList<QVariant> & result, const QVariant & id)
 {
-    qDebug() << id << result;
+    qCDebug(DRKONQI_LOG) << id << result;
 
     if (id.toString() == QLatin1String("login")) {
         if ((m_security == UseTokens) && (result.count() > 0)) {
@@ -450,7 +454,7 @@ void BugzillaManager::callMessage(const QList<QVariant> & result, const QVariant
 
 void BugzillaManager::callFault(int errorCode, const QString & errorString, const QVariant & id)
 {
-    qDebug() << id << errorCode << errorString;
+    qCDebug(DRKONQI_LOG) << id << errorCode << errorString;
 
     QString genericError = i18nc("@info", "Received unexpected error code %1 from bugzilla. "
                                  "Error message was: %2", errorCode, errorString);
@@ -508,10 +512,10 @@ BugMapList BugListCSVParser::parse()
         //Parse buglist CSV
         QTextStream ts(&m_data);
         QString headersLine = ts.readLine().remove(QLatin1Char('\"')) ;   //Discard headers
-        QString expectedHeadersLine = QString(columns);
+        QString expectedHeadersLine = QString::fromLatin1(columns);
 
         if (headersLine == (QStringLiteral("bug_id,") + expectedHeadersLine)) {
-            QStringList headers = expectedHeadersLine.split(',', QString::KeepEmptyParts);
+            QStringList headers = expectedHeadersLine.split(QLatin1Char(','), QString::KeepEmptyParts);
             int headersCount = headers.count();
 
             while (!ts.atEnd()) {
@@ -520,7 +524,7 @@ BugMapList BugListCSVParser::parse()
                 QString line = ts.readLine();
 
                 //Get bug_id (always at first column)
-                int bug_id_index = line.indexOf(',');
+                int bug_id_index = line.indexOf(QLatin1Char(','));
                 QString bug_id = line.left(bug_id_index);
                 bug.insert(QStringLiteral("bug_id"), bug_id);
 
